# status key values as defined by the Teaspoons service: https://github.com/DataBiosphere/terra-scientific-pipelines-service/blob/main/service/src/main/java/bio/terra/pipelines/common/utils/CommonPipelineRunStatusEnum.java
FAILED_KEY = "FAILED"
SUCCEEDED_KEY = "SUCCEEDED"
RUNNING_KEY = "RUNNING"
PREPARING_KEY = "PREPARING"

# input types as defined by the Teaspoons service: https://github.com/DataBiosphere/terra-scientific-pipelines-service/blob/main/service/src/main/java/bio/terra/pipelines/common/utils/PipelineVariableTypesEnum.java
STRING_TYPE_KEY = "STRING"
INTEGER_TYPE_KEY = "INTEGER"
FILE_TYPE_KEY = "FILE"
STRING_ARRAY_TYPE_KEY = "STRING_ARRAY"
FILE_ARRAY_TYPE_KEY = "FILE_ARRAY"

# file upload size limit
MAX_FILE_UPLOAD_SIZE_BYTES = 50 * 1025 * 1024 * 1024  # 50GB

# support text
SUPPORT_EMAIL = "scientific-services-support@broadinstitute.org"
SUPPORT_EMAIL_TEXT = f"For help troubleshooting, email {SUPPORT_EMAIL}"
